import { ILoadByUrlRule, IElementSelectorRule } from "./LoadableManifestRegistry";
import { IDependencyComposer, DependencyComposer } from "./DependencyComposer";
export interface IComponentOptions {
    /** The name for this component, this should be a none conflicting name
        e.g. use project as prefix myuniqueprojectname-componentName.
        i.e. <myuniqueprojectname-componentName></myuniqueprojectname-componentName> */
    elementName: string;
    /** The path for the start point for this component
        e.g. './ComponentFolder/Component.vue'
        Paths should be absolute (relative project root), or relative current folder
    */
    entryPoint: string;
    /** The desired bundle names or entry point components*/
    dependencies?: Array<string>;
}
export interface IComponentDefinition {
    /** The title shown for this component */
    title: string;
    /** (Optional)
        The description shown for this component */
    description?: string;
    /** (Optional)
        The icon shown for this component */
    icon?: string;
}
export interface IBuildOptions {
    /** (Optional)
        The name of the vendor packages this component is dependent on.
        node_modules packages:
        E.g. ['myExternalDependency',
              'myExternalDependency2/dist/myExternalDependency2-material.css',
              'myExternalDependency2/dist/myExternalDependency2-material.js']
    */
    vendor?: Array<string>;
}
export interface IComponentComposer extends IDependencyComposer {
    /** The definition for this component, information shown for the component while e.g. being displayed in component pickers */
    withDefinition: (definition: IComponentDefinition) => IComponentComposer;
    /** The build options for this component, e.g. options to influence bundling of the component when the project is built*/
    useBuildOptions: (buildOptions: IBuildOptions) => IComponentComposer;
    withDependency: (manifestId: string) => IDependencyComposer;
    /** Add a rule when the component should be loaded
        Make sure to add rules which is not to generic, i.e. only load when needed
    */
    loadByUrlRule: (loadRule: ILoadByUrlRule) => IComponentComposer;
    /**
        Add a rule that matches against DOM elements
        If matched this manifest is loaded
    */
    loadByElementRule: (elementRule: IElementSelectorRule) => IComponentComposer;
}
export declare class ComponentComposer implements IComponentComposer {
    private manifest;
    constructor(manifestId: string);
    registerComponent: (componentOptions: IComponentOptions) => this;
    withDefinition: (definition: IComponentDefinition) => IComponentComposer;
    useBuildOptions: (buildOptions: IBuildOptions) => IComponentComposer;
    loadByUrlRule: (loadRule: ILoadByUrlRule) => this;
    loadByElementRule: (elementRule: IElementSelectorRule) => this;
    withDependency: (manifestId: string) => DependencyComposer;
    withExternalDependency: (extensionId: string, manifestId: string) => DependencyComposer;
}
