import { BundleTargetType } from './Enums';
import { IClientManifest } from "./ManifestRegistry";
/**
    Rules applied clientside
    Every rule is executed and matched against the DOM
*/
export interface IElementSelectorRule {
    /**
        Loaded if an element is found which matches this selector.
        see: https://www.w3schools.com/cssref/css_selectors.asp
    */
    cssSelectors?: string;
}
export interface IClientManifestLoadableByElementRules {
    elementRules: Array<IElementSelectorRule>;
}
export declare class ElementRuleMerger {
    private rules;
    private ccsSelectors;
    add: (rule: IElementSelectorRule) => void;
    getUniqueRules: () => IElementSelectorRule[];
}
/**
    Rules applied clientside
    Every rule is compared to the current server relative url of the page
*/
export interface ILoadByUrlRule {
    /**
        For all urls starting with e.g. / - from and down root,
        /site1/page2 etc
    */
    startsWith?: string;
    /**
        Loaded if regEx matches current serverrelative path
    */
    regEx?: string;
}
export interface IClientManifestLoadableByUrl {
    loadByUrlRules: Array<ILoadByUrlRule>;
}
export declare class LoadByUrlRuleMerger {
    private rules;
    private regExps;
    private startsWith;
    add: (rule: ILoadByUrlRule) => void;
    getUniqueRules: () => ILoadByUrlRule[];
}
export interface IResourceManifest extends IClientManifest {
    /**
        The unique id of the manifest, this will be the id of the resources added.
    */
    resourceId: string;
}
export interface IManifestDependency {
    resourceId: string;
    extensionId: string;
}
export interface IClientLoadableResourceManifest extends IResourceManifest {
    version: string;
    /**
        The id of the extension to which the resource belong
    */
    extensionId: string;
    dependingOnManifests: Array<IManifestDependency>;
    availableBundleTargetTypes: Array<BundleTargetType>;
}
export interface IClientLoadableManifestProvider {
    getClientLoadableManifests: (currentExtensionId: string) => Array<IClientLoadableResourceManifest>;
    clearState: () => void;
}
export declare class LoadableManifestRegistry {
    private static ManifestDependencies;
    private static ManifestFileTypes;
    private static ManifestVersions;
    private static ClientManifests;
    private static RegisteredManifests;
    private static ClientManifestProviders;
    static getRegisteredManifest: (manifestId: string) => IResourceManifest;
    static addManifestDependency: (manifestId: string, dependentOnManifestId: string, dependentManifestExtensionId?: string) => void;
    static getManifestDependencies: (manifestId: string, currentExtensionId: string) => IManifestDependency[];
    static addManifestVersion: (manifestId: string, version: string) => void;
    static getManifestVersion: (manifestId: string) => string;
    static addManifestBundleType: (manifestId: string, type: BundleTargetType) => void;
    static getManifestBundleTypes: (manifestId: string) => BundleTargetType[];
    static registerManifest: (manifest: IResourceManifest) => IResourceManifest;
    static registerManifestProvider: (provider: IClientLoadableManifestProvider) => void;
    static getClientManifests: (currentExtensionId: string) => IClientManifest[];
    static clearState: () => void;
    private static validateDependencies;
    private static addClientManifest;
    private static Subscription;
}
