import { ILoadByUrlRule } from "./LoadableManifestRegistry";
import { IDependencyComposer, DependencyComposer } from "./DependencyComposer";
export interface IResourceDescription {
    /** The paths to the resources to include.
        e.g. './ResourceFolder/Resource.ts/css/sass etc.'
        paths should be absolute (relative project root), or relative current folder.
        Resources are bundled in the same order as resources appear's within the collection
    */
    resourcePaths: Array<string>;
    /** The desired bundle names or entry point components*/
    dependencies?: Array<string>;
}
export interface IOrderOptions {
    /** (Optional)
        The priority used while creating the bundle, i.e. if several manifests add resources to the same bundle name.
        Higher value will be added before a resources bundled with a manifest with a lower priority.
    */
    priority?: number;
}
export interface IResourceComposer extends IDependencyComposer {
    /** Add information about how resources should be ordered within the bundle */
    orderUsing: (orderOption: IOrderOptions) => IResourceComposer;
    /** Add a rule when the resource should be loaded
        Make sure to add rules which is not to generic, i.e. only load when needed
    */
    loadByUrlRule: (loadRule: ILoadByUrlRule) => IResourceComposer;
}
export declare class ResourceComposer implements IResourceComposer {
    private manifest;
    constructor(manifestId: string);
    registerResource: (resourceDescription: IResourceDescription) => this;
    orderUsing: (orderOption: IOrderOptions) => this;
    loadByUrlRule: (loadRule: ILoadByUrlRule) => this;
    withDependency: (manifestId: string) => DependencyComposer;
    withExternalDependency: (extensionId: string, manifestId: string) => DependencyComposer;
}
